@@ -83,5 +83,5 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
   }  else  est <- NULL
 
   rownames(be)  <- colnames(x)
-  list(runtime = runtime, be = be, covb = covb, est = est)
+  list(runtime = runtime, be = be, covbe = covb, est = est)
 }
