@@ -5,27 +5,25 @@ makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = FALSE) {
 
   if ( !stratified ) {
     oop <- options(warn = -1)
-    on.exit(options(oop))
-    ep <- sample( length(ina) )
-    nr <- round( length(ina)/nfolds )
-    mat <- matrix( ep[1:(nr * nfolds) ], ncol = nfolds )
-    mat[ -c( 1:length(ina) ) ] <- NA
-    for ( i in 1:nfolds ) runs[[ i ]] <- mat[, i]
-    rem <- ep[ - c(1:(nr * nfolds)) ]
-    ela <- sample(nfolds, length(rem))
-    if ( length(ela) > 0 )  for ( i in 1:length(ela) )  runs[[ ela[i] ]] <- c( runs[[ i ]], rem[ i ] )
+    rat <- length(ina) %% nfolds
+    mat <- matrix( sample( length(ina) ), ncol = nfolds )
+    mat[-c( 1:length(ina) )] <- NA
+    on.exit( options(oop) )
+    for ( i in 1:c(nfolds - 1) )  runs[[ i ]] <- mat[, i]
+    a <- prod(dim(mat)) - length(ina)
+    runs[[ nfolds ]] <- mat[1:c(nrow(mat) - a), nfolds]
   } else {
     labs <- unique(ina)
     run <- list()
     for (i in 1:length(labs)) {
       names <- which( ina == labs[i] )
-      run[[i]] <- sample(names)
+      run[[ i ]] <- sample(names)
     }
     run <- unlist(run)
     for ( i in 1:length(ina) ) {
       k <- i %% nfolds
       if ( k == 0 )  k <- nfolds
-      runs[[k]] <- c( runs[[ k ]], run[i] )
+      runs[[ k ]] <- c( runs[[ k ]], run[i] )
     }
   }
   for (i in 1:nfolds)  {
